MethodChannelBlisache class
- Inheritance
-
- Object
- PlatformInterface
- BlisachePlatform
- MethodChannelBlisache
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCredential(
RegisterInitResponse registerData, String login, String name) → Future< AttestationPublicKeyCredential> -
override
-
getCredential(
AuthenticateInitResponse authenticateData) → Future< AuthenticationPublicKeyCredential> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited