AuthenticateAllowCredential class

Annotations
  • @JsonSerializable.new(converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)

Constructors

AuthenticateAllowCredential(Uint8List id, String type, List<String> transports)
AuthenticateAllowCredential.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transports → List<String>
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited