AuthenticateInitResponse class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)
Constructors
- AuthenticateInitResponse(Uint8List? userLoginHash, String domain, AuthenticationData authenticationData)
-
AuthenticateInitResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authenticationData → AuthenticationData
-
final
- domain → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userLoginHash → Uint8List?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJsonModel(
Object? json) → AuthenticateInitResponse -
toJsonModel(
AuthenticateInitResponse obj) → Map< String, dynamic>