BlisacheErrorResponse class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

BlisacheErrorResponse(int timestamp, BlisacheAction action, BlisacheActionResult result, ErrorDescription causedBy)
BlisacheErrorResponse.fromJson(Map<String, dynamic> json)
factory

Properties

action BlisacheAction
final
causedBy ErrorDescription
final
hashCode int
The hash code for this object.
no setterinherited
result BlisacheActionResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited