BlisacheResponse<T> class

Annotations
  • @JsonSerializable.new(explicitToJson: true, genericArgumentFactories: true, fieldRename: FieldRename.snake)

Constructors

BlisacheResponse(int timestamp, String domain, BlisacheAction action, BlisacheResult result, T data)
BlisacheResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

action BlisacheAction
final
data → T
final
domain String
final
hashCode int
The hash code for this object.
no setterinherited
result BlisacheResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object toJsonT(T)) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited