RegisterCompleteRequest class

Annotations
  • @JsonSerializable.new(explicitToJson: true, converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)

Constructors

RegisterCompleteRequest(int id, String domain, Uint8List loginHash, AttestationPublicKeyCredential credential)
RegisterCompleteRequest.fromJson(Map<String, dynamic> json)
factory

Properties

credential → AttestationPublicKeyCredential
final
domain → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
loginHash → Uint8List
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited