RegisterInitResponse class

Annotations
  • @JsonSerializable.new(explicitToJson: true, fieldRename: FieldRename.snake)

Constructors

RegisterInitResponse(User user, String domain, RegistrationData registrationData)
RegisterInitResponse.fromJson(Map<String, dynamic> json)
factory

Properties

domain → String
final
hashCode → int
The hash code for this object.
no setterinherited
registrationData → RegistrationData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → User
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonModel(Object? json) → RegisterInitResponse
toJsonModel(RegisterInitResponse obj) → Map<String, dynamic>