SignedResponse class

Annotations
  • @JsonSerializable.new(converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)

Constructors

SignedResponse(Uint8List message, Uint8List signature)
SignedResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited