BlisachePlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- BlisachePlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCredential(
RegisterInitResponse registerData, String login, String name) → Future< AttestationPublicKeyCredential> -
getCredential(
AuthenticateInitResponse authenticateData) → Future< AuthenticationPublicKeyCredential> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ BlisachePlatform
-
Platform-specific implementations should set this with their own
platform-specific class that extends BlisachePlatform when
they register themselves.
getter/setter pair