AuthenticationData class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)
Constructors
-
AuthenticationData(int id, Uint8List challenge, UserVerificationRequirement userVerification, List<
AuthenticateAllowCredential> ? allowedCredentials) -
AuthenticationData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedCredentials
→ List<
AuthenticateAllowCredential> ? -
final
- challenge → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userVerification → UserVerificationRequirement
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited