AuthenticatorAssertionResponse class
- Annotations
-
- @JsonSerializable.new(converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)
Constructors
- AuthenticatorAssertionResponse(Uint8List authenticatorData, Uint8List clientDataJson, Uint8List signature, Uint8List? user_handle)
-
AuthenticatorAssertionResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authenticatorData → Uint8List
-
final
- clientDataJson → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → Uint8List
-
final
- user_handle → Uint8List?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited