RegistrationData class
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, converters: [Uint8listJsonConverter()], fieldRename: FieldRename.snake)
Constructors
-
RegistrationData(int id, Uint8List challenge, AuthenticatorAttachment authenticatorAttachment, ResidentKeyRequirement residentKey, UserVerificationRequirement userVerification, AttestationConveyancePreference attestationConveyancePreference, UserIdValidationConstraint userIdValidationConstraint, List<
PubKeyCredParam> publicKeyCredentialParams) -
RegistrationData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attestationConveyancePreference → AttestationConveyancePreference
-
final
- authenticatorAttachment → AuthenticatorAttachment
-
final
- challenge → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
-
publicKeyCredentialParams
→ List<
PubKeyCredParam> -
final
- residentKey → ResidentKeyRequirement
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userIdValidationConstraint → UserIdValidationConstraint
-
final
- userVerification → UserVerificationRequirement
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited